package Bundle::Maypole;

use strict;

our $VERSION = '0.02';

=head1 NAME

Bundle::Maypole - All Maypole goodness

=head1 SYNOPSIS

C<perl -MCPAN -e 'install Bundle::Maypole'>

=head1 DESCRIPTION

Installs all the Maypole modules for you.

=head1 CONTENTS

Maypole

Maypole::View::Mason

Maypole::Plugin::Authentication::UserSessionCookie

Maypole::Plugin::Component

Maypole::Plugin::Config-YAML

Maypole::Plugin::Exception

Maypole::Plugin::I18N

Maypole::Plugin::Loader

Maypole::Plugin::Relationship

Maypole::Plugin::Transaction

Maypole::Plugin::Untaint

=head1 AUTHOR

Sebastian Riedel, C<sri@oook.de>.  Modified to work and changing to more commonly used Authentication module by Kieren Diment C<kd@totaldatasolution.com>

=head1 LICENSE

This library is free software. You can redistribute it and/or modify it under
the same terms as perl itself.

=cut

1;
